Learn R Programming

locpolExpectile (version 0.1.1)

ParLin_expectreg_hetero: Partially linear expectile regression with different possible heteroscedastic error and univariate variable in the nonparametric function

Description

Formula interface for the partially linear expectile regression using local linear expectile estimation for different heteroscedastic error structure and a univariate variable in the nonparametric function \(g(.)\). The model is of the form \(Y=\delta^T X + g(Z) + \sigma(X) \epsilon\), \(Y=\delta^T X + g(Z) + \sigma(Z) \epsilon\) or \(Y=\delta^T X + g(Z) + \sigma(Z,X) \epsilon\). See Table 1 in Adam and Gijbels (2021b) for more details.

Usage

ParLin_expectreg_hetero(
  X,
  Y,
  Z,
  omega = 0.3,
  kernel = gaussK,
  heteroscedastic = c("X", "Z", "Z and X")
)

Arguments

X

The covariates data values for the linear part (of size \(n \times k\) with k=1 or k=2).

Y

The response data values.

Z

The covariate data values for the nonparametric part.

omega

Numeric vector of level between 0 and 1 where 0.5 corresponds to the mean.

kernel

The kernel used to perform the estimation. In default setting, kernel=gaussK. See details in Kernels.

heteroscedastic

Heteroscedastic error depending on X, or onZ or on Z and X

Value

ParLin_expectreg_hetero partially linear expectile estimators for different heteroscedastic error structures and a univariare variable in the nonparametric part, proposed and studied by Adam and Gijbels (2021b). ParLin_expectreg_hetero returns a list whose components are:

  • If the heteroscedastic error depends on \(Z\):

    • Linear The delta estimators for the linear part

    • Nonlinear The estimation of the nonparametric part according to the observed values \(Z_i\).

  • If the heteroscedastic error depends on \(X\):

    • Linear The delta estimators for the linear part

    • Nonlinear_g The estimation of the nonparametric part according to the observed values \(Z_i\).

    • Nonlinear_g_omega The estimation of the nonparametric part according to the observed values \(X_i\) (if \(X\) is univariate) or to the couple of observed values \((X_{1i},X_{2j})\).

  • If the heteroscedastic error depends on \(Z\) and \(X\):

    • Linear The delta estimators for the linear part

    • Nonlinear_g The estimation of the nonparametric part according to the couple of the observed values \((Z_i,X_j)\) (if \(X\) is univariate) or to the observed values \((Z_i,X_{1i},X_{2i})\).

References

Adam, C. and Gijbels, I. (2021b). Partially linear expectile regression using local polynomial fitting. In Advances in Contemporary Statistics and Econometrics: Festschrift in Honor of Christine Thomas-Agnan, Chapter 8, pages 139<U+2013>160. Springer, New York.

Examples

Run this code
# NOT RUN {
library(locpol)
set.seed(123)
Z<-runif(100,-3,3)
eta_1<-rnorm(100,0,1)
X1<-(0.9*Z)+(1.5*eta_1)
set.seed(1234)
eta_2<-rnorm(100,0,2)
X2<-(0.9*Z)+(1.5*eta_2)
X<-rbind(X1,X2)

set.seed(12345)
epsilon<-rnorm(100,0,1)
delta<-rbind(0.8,-0.8)

Y<-as.numeric((t(delta)%*%X)+(10*sin(0.9*Z))+(0.6*X1^2)*epsilon)

ParLin_expectreg_hetero(X=t(X),Y=Y,Z=Z,omega=0.3,kernel=gaussK,heteroscedastic="X")
# }

Run the code above in your browser using DataLab