Formula interface for the local linear expectile estimation for a trivariate covariate setting.
expectreg_loclin_trivariate(Z, X1, X2, Y, omega, h, kernel = gaussK)The first covariate data values.
The second covariate data values.
The third covariate data values.
The response data values.
Numeric vector of level between 0 and 1 where 0.5 corresponds to the mean.
Smoothing parameter, bandwidth.
The kernel used to perform the estimation. In default setting,
kernel=gaussK. See details in Kernels.
expectreg_loclin_trivariate local linear expectile estimator
proposed and studied by Adam and Gijbels (2021b) for a trivariate covariate matrix.
expectreg_loclin_trivariate returns a vector whose components are
the estimation of the nonparametric part according to the observed values
(i.e. \((Z_i,X_{1i},X_{2i})\)).
Adam, C. and Gijbels, I. (2021b). Partially linear expectile regression using local polynomial fitting. In Advances in Contemporary Statistics and Econometrics: Festschrift in Honor of Christine Thomas-Agnan, Chapter 8, pages 139<U+2013>160. Springer, New York.